@@ -4,17 +4,30 @@ import hashlib
 from dotenv import load_dotenv
 
 from manim_voiceover.services.base import SpeechService
-from pyttsx3 import Engine
 
+try:
+    from pyttsx3 import Engine
+except ImportError:
+    print(
+        'Missing packages. Run `pip install "manim-voiceover[pyttsx3]"` to use Pyttsx3Service.'
+    )
 load_dotenv()
 
 
 class PyTTSX3Service(SpeechService):
-    def __init__(self, engine: Engine, **kwargs):
+    """Speech service class for pyttsx3."""
+    def __init__(self, engine=None, **kwargs):
+        ""
+        if engine is None:
+            engine = Engine()
+
         self.engine = engine
         SpeechService.__init__(self, **kwargs)
 
-    def generate_from_text(self, text: str, output_dir: str = None, path: str = None) -> dict:
+    def generate_from_text(
+        self, text: str, output_dir: str = None, path: str = None
+    ) -> dict:
+        ""
         if output_dir is None:
             output_dir = self.output_dir
 
